# Skill Registry — polyfit-image-compress

Auto-generated by sdd-init. Excludes SDD phase skills, _shared, and skill-registry.

## Skills

| Name | Path | Trigger |
|------|------|---------|
| go-testing | `~/.claude/skills/go-testing/SKILL.md` | Writing Go tests, using teatest, adding test coverage |
| skill-creator | `~/.claude/skills/skill-creator/SKILL.md` | Creating a new skill, adding agent instructions, documenting patterns for AI |
| project-brainstorming | `~/.claude/skills/project-brainstorming/SKILL.md` | New project idea with no existing codebase — "I want to build...", "new project" |
| systematic-debugging | `~/.claude/skills/systematic-debugging/SKILL.md` | Bug reports, test failures, errors during sdd-apply |
| verification-before-completion | `~/.claude/skills/verification-before-completion/SKILL.md` | Before declaring work done, saying "done"/"finished", before creating a PR |
| git-worktrees | `~/.claude/skills/git-worktrees/SKILL.md` | Starting a new SDD change, "new feature", before sdd-apply |
| git-flow | `~/.claude/skills/git-flow/SKILL.md` | Commit, push, create branches, manage PRs. Also invoked as /git-flow |

## Project Conventions

| File | Path |
|------|------|
| CLAUDE.md | `/home/jelsin/Proje/polyfit-image-compress/CLAUDE.md` |
| git-manager agent | `/home/jelsin/Proje/polyfit-image-compress/.claude/agents/git-manager.md` |
